%define anolis_release 1
%bcond_with tests
%bcond_with doc

Name:           python-hypothesis
Version:        6.70.0
Release:        %{anolis_release}%{?dist}
Summary:        Library for property based testing

License:        MPLv2.0
URL:            https://github.com/HypothesisWorks/hypothesis
Source0:        %{url}/archive/hypothesis-python-%{version}/hypothesis-python-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros >= 0-43

%if %{with tests}
# optional test dependencies:
BuildRequires:  %{py3_dist typing_extensions}
%endif

%if %{with doc}
BuildRequires:  %{_bindir}/sphinx-build
BuildRequires:  %{py3_dist sphinx-hoverxref}
BuildRequires:  %{py3_dist sphinx-rtd-theme}
BuildRequires:  %{py3_dist sphinx_selective_exclude}
%endif


%global _description %{expand:
Hypothesis is a library for testing your Python code against a much
larger range of examples than you would ever want to write by
hand. It’s based on the Haskell library, Quickcheck, and is designed
to integrate seamlessly into your existing Python unit testing work
flow.}

%description %{_description}


%package     -n python3-hypothesis
Summary:        %{summary}

%description -n python3-hypothesis %{_description}

%package     -n python3-hypothesis-doc
Summary:        %{summary}
Requires: 	python3-hypothesis = %{version}-%{release}

%description -n python3-hypothesis-doc

%global extras cli,ghostwriter,pytz,dateutil,lark,numpy,pandas,pytest,redis,zoneinfo,django,codemods
# extras with missing deps:
#  dpcontracts: dpcontracts
%{pyproject_extras_subpkg -n python3-hypothesis %{extras}}


%prep
%autosetup -n hypothesis-hypothesis-python-%{version}/hypothesis-python -p2
# disable Sphinx extensions that require Internet access
sed -i -e '/sphinx.ext.intersphinx/d' docs/conf.py
# disable Sphinx non-available extensions
sed -i -e '/sphinx_codeautolink/d' docs/conf.py
# use Fedora-packaged lark-parser until the package is renamed to lark
# the comment near this dependency says:
#   "probably still works with old `lark-parser` too"
sed -i -e 's/"lark>=0.10.1"/"lark-parser>=0.9"/' setup.py


%generate_buildrequires
%pyproject_buildrequires %{?with_tests:../requirements/test.in -x %{extras}}


%build
%pyproject_wheel

%if %{with doc}
PYTHONPATH=src READTHEDOCS=True sphinx-build -b man docs docs/_build/man
%endif


%install
%pyproject_install
%pyproject_save_files hypothesis '_hypothesis_*'

%if %{with doc}
install -Dpm0644 -t %{buildroot}%{_mandir}/man1 docs/_build/man/hypothesis.1
%endif


%if %{with tests}
%check
k="not test_registered_from_entrypoint"

%pytest -v -n auto -k "$k" \
  --ignore tests/dpcontracts \
  --ignore tests/redis \

# The BRP that handles bytecompilation already run at the end of %%install.
# This autogenerated file gets re-generated during tests,
# the tests asserts the content is identical, but the mtime is changed anyway.
# Since %%pytest disables byte-compilation, we need to update the pycs manually:
%py_byte_compile %{python3} %{buildroot}%{python3_sitelib}/hypothesis/internal/conjecture/shrinking/learned_dfas.py
%endif


%files -n python3-hypothesis -f %{pyproject_files}
%license ../LICENSE.txt
%{_bindir}/hypothesis
%if %{with doc}
%{_mandir}/man1/hypothesis.1*
%endif

%files -n python3-hypothesis-doc
%doc README.rst

%changelog
* Fri Mar 17 2023 happy_orange <songnannan@linux.alibaba.com> - 6.70.0-1
- package init from upstream
